@@ -24,6 +24,7 @@ from socket import gaierror
 from struct import pack, unpack
 
 from dmidecode import DMIDecode
+from pyroute2 import IPDB
 
 ## Magic constants from `/usr/include/linux/if_ether.h`:
 ETH_P_ALL = 0x0003
@@ -210,14 +211,15 @@ class nads(JobServerPlugin):
     return True
 
 
-  def getMac(self):
-    s = socket(AF_INET, SOCK_DGRAM)
-    info = fcntl.ioctl(s.fileno(), 0x8927,  struct.pack('256s', bytes(self.provIntf, 'utf-8')))
-    # print(info[18:24])
-    # for byte in info[18:24]:
+  # def getMac(self):
+
+    # s = socket(AF_INET, SOCK_DGRAM)
+    # info = fcntl.ioctl(s.fileno(), 0x8927,  struct.pack('256s', bytes(self.provIntf, 'utf-8')))
+    # # print(info[18:24])
+    # # for byte in info[18:24]:
       
-    #   print(hex(byte))
-    return ':'.join(['%02x' % char for char in info[18:24]])
+    # #   print(hex(byte))
+    # return ':'.join(['%02x' % char for char in info[18:24]])
 
   
   def handle_jobs(self):
@@ -239,9 +241,13 @@ class nads(JobServerPlugin):
     # Try all the interfaces, first one to give us an LLDP packet is our winner.
     # TODO: Maybe allow for  trying multiple interfaces even if an LLDP is detected
     # but registration fails?
+    ipdb = IPDB()
     for iface in netifaces.interfaces():
       if iface == 'lo':
         continue
+      # check if the interface is operationally up.
+      if ipdb.interfaces[iface].operstate != "UP":
+        continue
       print(f"Attempting LLDP Capture on {iface}")
       self.provIntf = iface
       try:
@@ -250,7 +256,10 @@ class nads(JobServerPlugin):
         print(f"{e}")
         lldpRes = False
       if lldpRes:
+        # grab the mac of the prov interface.
+        self.mac = netifaces.ifaddresses(self.provIntf)[socket.AF_PACKET]['addr']
         break
+    ipdb.release()
     # and now, we are supposed to turn it backon again.....
     for ifaceCmdFile in ifceCmdFiles:
       try:
@@ -264,8 +273,7 @@ class nads(JobServerPlugin):
 
       return False
 
-    # grab the mac of the prov interface.
-    self.mac = self.getMac()
+    
 
     if self.port.find('/') >= 0:
       # we need to parse the port out of the port id.
